#include "project.h"
#include "stdio.h"
#include "tty_utils.h"

volatile int32_t sensor1_period = 0 ;
volatile int     sensor1_flag = 0 ;

void sensor_irq1_isr(void)
{
    int32_t source ;
    sensor1_flag = 1 ;
    source = Counter_1_GetInterruptStatus() ;
    sensor1_period = Counter_1_GetCapture() ;
    Counter_1_ClearInterrupt(source) ;
}

void sensor_irq1_init(void)
{
    const cy_stc_sysint_t SysInt_1_cfg = {
        .intrSrc = (IRQn_Type)SysInt_1__INTC_NUMBER,
        .intrPriority = SysInt_1__INTC_CORTEXM4_PRIORITY
    } ;
    Cy_SysInt_Init(&SysInt_1_cfg, sensor_irq1_isr) ;
    NVIC_ClearPendingIRQ(SysInt_1_cfg.intrSrc) ;
    NVIC_EnableIRQ((IRQn_Type)SysInt_1_cfg.intrSrc) ;
}

void init_hardware(void)
{
    __enable_irq(); /* Enable global interrupts. */    
    
    tty_init() ;
    
    sensor_irq1_init() ;
    
    Counter_1_Start() ;
    
    Counter_2_Start() ;
    
}

int main(void)
{
    int32_t prev_period = 0 ;
    int32_t period = 0 ;
    int32_t test_period = 0 ;
    int32   count = 0 ;
    
    init_hardware() ;
    
    cls() ;
    
    splash("PSoC 6 Interval Timer Test") ;

    for(;;)
    {
        if (sensor1_flag) {
            period = sensor1_period ;
            sensor1_flag = 0 ;
            if (prev_period != period) {
                snprintf(str, STR_BUF_LEN, "Sensor1: %d\n\r", period) ;
                print(str) ;
                prev_period = period ;
            }
            count++ ;
            if ((count % 100) == 0) {
                count = 0 ;
                test_period = Counter_2_GetPeriod() ;
                test_period = test_period + 1 ;
                if (test_period > 200) {
                    test_period = 50 ;
                }
                Counter_2_Disable() ;
                Counter_2_SetPeriod(test_period) ;
                Counter_2_Enable() ;
                Counter_2_TriggerStart() ;
            }
        }
    }
}